from enum import Enum


class UnitVolumeFormat(str, Enum):
    CUBIC_METER = 'cubic_meter'
    CUBIC_MILLIMETER = 'cubic_millimeter'
    CUBIC_KILOMETER = 'cubic_kilometer'
    LITER = 'liter'
    CUBIC_FOOT = 'cubic_foot'
    CUBIC_YARD = 'cubic_yard'
    CUBIC_MILE = 'cubic_mile'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitConcentrationFormat(str, Enum):
    PARTS_PER_MILLION = 'parts_per_million'
    PARTS_PER_BILLION = 'parts_per_billion'
    PARTS_PER_TRILLION = 'parts_per_trillion'
    PERCENT = 'percent'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitLengthFormat(str, Enum):
    METER = 'meter'
    FOOT = 'foot'
    INCH = 'inch'
    MILE = 'mile'
    NAUTICAL_MILE = 'nautical_mile'
    ASTRONOMICAL_UNIT = 'astronomical_unit'
    CUBIT = 'cubit'
    FATHOM = 'fathom'
    CHAIN = 'chain'
    FURLONG = 'furlong'
    HAND = 'hand'
    LEAGUE = 'league'
    NAUTICAL_LEAGUE = 'nautical_league'
    YARD = 'yard'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitPressureFormat(str, Enum):
    PASCAL = 'pascal'
    BAR = 'bar'
    MBAR = 'mbar'
    ATMOSPHERE = 'atmosphere'
    POUNDS_PER_SQUARE_INCH = 'pounds_per_square_inch'

    def __str__(self) -> str:
        return str(self.value)
